bayespy.inference.vmp.nodes.binomial.BinomialMoments.__init__
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialMoments.__init__